# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/question.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Wolfram Alpha

## Summary

General knowledge fallback handler based on [Wolfram Alpha](https://wolframalpha.com) services

## Description

Answers general knowledge, math, and definition questions by using Wolfram Alpha
API services. If the user is interested in knowing where the information for the
spoken answer came from, Neon can send the most recent source of the spoken 
details to user’s email.

Use of this skill requires use of third-party APIs. This skill will use Neon AI
servers by default, but you can deploy your own instance of 
[Diana](https://github.com/NeonGeckoCom/neon-diana-utils).

## Examples

Ask Neon any questions starting with `What`, `Why`, or `How`
- What is 2 + 2?
- Who won best picture in 2006?
- How far away is the moon?

To receive an email with related information:
- Send me the source for that.

> **Please note that Neon will ask for your email address and name if this information is not currently available in your user settings.**

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[Mycroft AI](https://github.com/MycroftAI)
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)

